@@ -102,7 +102,7 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False) :
         m = re.search(r"<div (class|id)=\"content\".*?>(.*?)</div>",rsp.text,re.DOTALL)
         context = ""
         if m :
-            context = m.group(2).replace("</br>","</br>\n")
+            context = m.group(2).replace("<br/>","</br>\n")
             context = m.group(2).replace("<br/>","<br/>\n")
         else :
             lines = [ln for ln in rsp.text.splitlines()]
@@ -118,8 +118,8 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False) :
         if len(context) < 200 :
             print("# context length abnormal. most likely hit with rate limiter", file=sys.stderr, flush=True)
             break
-        if not re.search(r"</br>\s*</br>",context,re.DOTALL) :
-            context = context.replace("</br>","</br></br>")
+        if not re.search(r"<br/>\s*</br>",context,re.DOTALL) :
+            context = context.replace("<br/>","</br></br>")
         if not re.search(r"<br/>\s*<br/>",context,re.DOTALL) :
             context = context.replace("<br/>","<br/><br/>")
         if ix == 0 :
@@ -140,17 +140,24 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False) :
         rtext += ps.replace("prevpg",prevpg).replace("nextpg",nextpg)
         rtext += "</head>\n"
         rtext += "<body style=\"background-color: #EAF2F8;color: #000000;\">\n"
-        rtext += "<a href=\"{}\">PREV CHAPTER</a><br/><br/>\n".format(prevpg)
-        #rtext += "&nbsp;"*10
-        rtext += "<a href=\"{}\">NEXT CHAPTER</a></br>\n".format(nextpg)
-        rtext += "</br></br>\n"
+        rtext += "<a href=\"index.html\">INDEX of {}</a>\n".format(title)
+        rtext += "<br/>\n"*2
+        rtext += "<a href=\"{}\">PREV CHAPTER</a>\n".format(prevpg)
+        rtext += "<br/>\n"*2
+        rtext += "<a href=\"{}\">NEXT CHAPTER</a><br/>\n".format(nextpg)
+        rtext += "<h3>{}</h3>".format(title) + "\n"
+        rtext += "<h4>{}</h4>".format(chapter) + "\n"
+        rtext += "<br/>\n"
         rtext += context + "\n"
-        rtext += "</br></br>\n"
-        rtext += "<a href=\"{}\">PREV CHAPTER</a><br/><br/>\n".format(prevpg)
-        #rtext += "&nbsp;"*10
-        rtext += "<a href=\"{}\">NEXT CHAPTER</a><br/><br/><br/><br/>\n".format(nextpg)
-        rtext += "<a href=\"index.html\">index</a><br/><br/>\n"
-        rtext += "<a href=\"{}\">orignal link</a><br/>\n".format(url)
+        rtext += "<br/></br>\n"
+        rtext += "<a href=\"{}\">PREV CHAPTER</a>\n".format(prevpg)
+        rtext += "<br/>\n"*2
+        rtext += "<a href=\"{}\">NEXT CHAPTER</a><br/>\n".format(nextpg)
+        rtext += "<br/>\n"*2
+        rtext += "<a href=\"index.html\">INDEX of {}</a>\n".format(title)
+        rtext += "<br/>\n"*2
+        rtext += "<a href=\"{}\">ORIGIN_SOURCE</a><br/>\n".format(url)
+        rtext += "<br/>\n"*2
         rtext += "</body>\n"
         rtext += "</html>\n"
         with open(os.path.join(tgtdir,title, cname),"w") as f :
@@ -162,7 +169,7 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False) :
                 hcontent = "<tr><td><a href=\"{}\">{}</a></td></tr>".format(cname,chapter) + "\n"
                 f.write(hcontent)
                 if not report :
-                    report += "{} - {} ".format(title,chapter)
+                    report += "{} :   {} ".format(title,chapter)
                 else :
                     report += ", {}".format(chapter)
             downloaded.add(cname)
